@@ -38,7 +38,8 @@
                       range = NULL,
                       endemism = 'WEI',
                       cores = 1,
-                      MEM = FALSE){
+                      MEM = FALSE,
+                      eval = TRUE){
   ## Argument checking function
   ## Occurrences, Environment, and part of
   ## X, Y, Pcol are directly defined in functions
@@ -218,6 +219,9 @@
   if (!is.null(richness)) {
     warning("Richness check arg to implement !")
   }
+  if (!inherits(eval, "logical")) {
+    stop("eval parameter should be a logical (True or False).")
+  }
 
   # load.occ and load.var
   if (!inherits(GeoRes, "logical")) {
@@ -233,8 +237,8 @@
     stop("files parameter should be characters or NULL")
   }
   if (!is.null(format) && !inherits(format, "character") || (inherits(format,
-                                                                      "character") && !(format %in% c(".grd", ".tif", ".asc", ".sdat", ".rst",
-                                                                                                      ".nc", ".tif", ".envi", ".bil", ".img")))) {
+                                                                      "character") && any(!(format %in% c(".grd", ".tif", ".asc", ".sdat", ".rst",
+                                                                                                          ".nc", ".tif", ".envi", ".bil", ".img"))))) {
     stop("format parameter should be .grd, .tif, .asc, .sdat, .rst, .nc, .tif, .envi, .bil or .img")
   }
   if (!inherits(categorical, "character") && !is.null(categorical)) {
