@@ -14,23 +14,11 @@ setMethod("project", "Algorithm.SDM", function(obj, Env, ...) {
   factors[sapply(factors, is.null)] <- NULL
   names(factors) <- unlist(sapply(seq_len(length(Env@layers)), function(i)
     if(Env[[i]]@data@isfactor) names(Env[[i]])))
+  if(length(factors)==0) factors <- NULL
   proj = suppressWarnings(raster::predict(Env, model, factors = factors))
-  # proj = suppressWarnings(raster::predict(Env, model, fun = function(model,
-  #                                                                    x) {
-  #   x = as.data.frame(x)
-  #   for (i in seq_len(length(Env@layers))) {
-  #     if (Env[[i]]@data@isfactor) {
-  #       x[, i] = as.factor(x[, i])
-  #       x[, i] = droplevels(x[, i])
-  #       levels(x[, i]) = Env[[i]]@data@attributes[[1]]$ID
-  #     }
-  #   }
-  #   return(predict(model, x))
-  # }))
-  # Rescaling projection
   proj = reclassify(proj, c(-Inf, 0, 0))
   if(all(obj@data$Presence %in% c(0,1))) # MEMs should not be rescaled
-    proj = proj / proj@data@max
+    if(proj@data@max > 0) proj = proj / proj@data@max
   names(proj) = "Projection"
   obj@projection = proj
   if(all(obj@data$Presence %in% c(0,1))) # MEMs can't produce binary
@@ -55,7 +43,7 @@ setMethod("project", "MAXENT.SDM", function(obj, Env, ...) {
   # Rescaling projection
   proj = reclassify(proj, c(-Inf, 0, 0))
   if(!all(obj@data$Presence %in% c(0,1))) # MEMs should not be rescaled
-    proj = proj / proj@data@max
+    if(proj@data@max > 0) proj = proj / proj@data@max
   names(proj) = "Projection"
   obj@projection = proj
   if(all(obj@data$Presence %in% c(0,1))) # MEMs can't produce binary
